Metric
======

.. currentmodule:: pykeen.metrics

.. autoclass:: Metric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Metric.binarize
      ~Metric.key
      ~Metric.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~Metric.get_description
      ~Metric.get_link
      ~Metric.get_range

   .. rubric:: Attributes Documentation

   .. autoattribute:: binarize
   .. autoattribute:: key
   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
